@@ -1,7 +1,7 @@
 package Parse::Number::EN;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-06-14'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 # TODO: make it OO and customize thousand sep & decimal point
 
@@ -9,7 +9,7 @@ use 5.010001;
 use strict;
 use warnings;
 
-use Exporter::Lite;
+use Exporter qw(import);
 our @EXPORT_OK = qw($Pat parse_number_en);
 
 our %SPEC;
@@ -72,7 +72,7 @@ Parse::Number::EN - Parse number from English text
 
 =head1 VERSION
 
-This document describes version 0.06 of Parse::Number::EN (from Perl distribution Parse-Number-EN), released on 2015-09-03.
+This document describes version 0.07 of Parse::Number::EN (from Perl distribution Parse-Number-EN), released on 2016-06-14.
 
 =head1 SYNOPSIS
 
@@ -92,6 +92,15 @@ The goal for this module is to parse/extract numbers written in some common
 notation in English text. That means, in addition to what Perl does, it also
 recognizes thousand separators (and fractions, percentages in the future).
 
+=head1 VARIABLES
+
+None are exported by default, but they are exportable.
+
+=head2 $Pat (REGEX)
+
+A regex for quickly matching/extracting number from text. It's not 100% perfect
+(the extracted number might not be valid), but it's simple and fast.
+
 =head1 FUNCTIONS
 
 
@@ -104,6 +113,8 @@ This function can parse number with thousand separators (e.g. 10,000).
 In the future percentage (e.g. 10.2%) and fractions (e.g. 1/3, 2 1/2) might also
 be supported.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -116,15 +127,6 @@ The input text that contains number.
 
 Return value:  (any)
 
-=head1 VARIABLES
-
-None are exported by default, but they are exportable.
-
-=head2 $Pat (REGEX)
-
-A regex for quickly matching/extracting number from text. It's not 100% perfect
-(the extracted number might not be valid), but it's simple and fast.
-
 =head1 FAQ
 
 =head2 How does this module differ from other number-parsing modules?
@@ -132,12 +134,6 @@ A regex for quickly matching/extracting number from text. It's not 100% perfect
 This module uses a single regex and provides the regex for you to use. Other
 modules might be more accurate and/or faster. But this module is pretty fast.
 
-=head1 SEE ALSO
-
-L<Lingua::EN::Words2Nums>
-
-Other Parse::Number::* modules (for other languages).
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Parse-Number-EN>.
@@ -154,13 +150,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Lingua::EN::Words2Nums>
+
+Other Parse::Number::* modules (for other languages).
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
